/*
    AttendanceManager
    Copyright (C) 2010  Victor Carceler

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as
    published by the Free Software Foundation, either version 3 of the
    License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>
 */

/*
 * Usage: AM_AddStundentsToGroup <propertiesfile> <in.csv> <groupid>
 * 
 * Assigns students <in.csv> to group <groupid>
 * 
 * <propertiesfile> Java properties file with database connection parameters
 * <in.csv> CSV file with students already en db. Header: "idstudent"
 * <groupid> ID of the group
 */

package org.iespuigcastellar.amtools;


import java.nio.charset.Charset;
import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.Statement;
import java.util.Properties;
import java.io.FileInputStream;
import com.csvreader.CsvReader;

public class AM_AddStudentsToGroup {

	private Properties properties;
	private Connection con;
	private Statement statement;
	
	private CsvReader incsv;
	
	public AM_AddStudentsToGroup(String propertiesname, String incsv) {
		try {
			FileInputStream file = new FileInputStream(propertiesname); 
			properties = new Properties();
			properties.load(file);
			file.close();
			
			Class.forName("com.mysql.jdbc.Driver");
			String url = "jdbc:mysql://" + properties.getProperty("mysql_server") + ":" + properties.getProperty("mysql_port") + "/" + properties.getProperty("mysql_database");
			con = DriverManager.getConnection(url, properties.getProperty("mysql_user"), properties.getProperty("mysql_password"));
			statement = con.createStatement();
			
			this.incsv = new CsvReader(incsv, ',', Charset.forName("UTF-8"));
			this.incsv.readHeaders();
			String headers[] = this.incsv.getHeaders();

			if(this.incsv.getIndex("idstudent") == -1 ){
				System.err.println("AM_AddStudentToGroup: Wrong in.csv format");
				System.err.println(headers[0]);
				System.exit(2);
			}
		} catch (Exception e) {
			System.err.println("AM_AddStudentsToGroup: Init error !!!");
			System.err.println(e);
		}
	}
	/**
	 * @param args
	 * @throws Exception 
	 */
	public static void main(String[] args) throws Exception {
		if(args.length!=3) {
			System.err.println("Usage: AM_AddStudentsToGroup <propertiesfile> <in.csv> <idgroup>\n\n" +
  
					"Assigns students <in.csv> to group <groupid>\n" +
					"\n\n" +
  
					"<propertiesfile> Java properties file with database connection parameters\n" +
					"<in.csv> CSV file with students. Header: 'idstudent'\n" +
					"<idgroup> ID of the group to assign students");
			System.exit(1);
		}
		
		AM_AddStudentsToGroup app = new AM_AddStudentsToGroup(args[0], args[1]);
		app.doit(args[2]);
	}
	
	private void doit(String idgroup) throws Exception {
		
		while (incsv.readRecord()) {
			statement.execute("INSERT INTO group_has_student VALUES('"+ idgroup + "', '" + incsv.get("idstudent") + "');");
		}
		
		incsv.close();
		con.close();
	}

}
