/*
    AttendanceManager
    Copyright (C) 2010  Victor Carceler

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as
    published by the Free Software Foundation, either version 3 of the
    License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>
 */

/*
 * Usage: AM_CSVMissReport <propertiesfile> <startdate> <enddate> <idgroup> <out.csv>
 * 
 * Writes a miss count report in out.csv for a group.
 * 
 * <propertiesfile> Java properties file with database connection parameters
 * <startdate> SQL Date, report only counts misses after this date (included)
 * <enddate> SQL Date, report only counts misses befor this date (included)
 * <idgroup>
 * <out.csv> output report
 */


package org.iespuigcastellar.amtools;

import java.io.FileInputStream;
import java.nio.charset.Charset;
import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.ResultSet;
import java.sql.Statement;
import java.util.Properties;

import com.csvreader.CsvWriter;

public class AM_CSVMissReport {

	private Properties properties;
	private Connection con;
	private Statement statement;
	
	private CsvWriter outcsv;

	
	public AM_CSVMissReport(String propertiesname, String outcsv) {
		try {
			FileInputStream file = new FileInputStream(propertiesname); 
			properties = new Properties();
			properties.load(file);
			file.close();
			
			Class.forName("com.mysql.jdbc.Driver");
			String url = "jdbc:mysql://" + properties.getProperty("mysql_server") + ":" + properties.getProperty("mysql_port") + "/" + properties.getProperty("mysql_database");
			con = DriverManager.getConnection(url, properties.getProperty("mysql_user"), properties.getProperty("mysql_password"));
			statement = con.createStatement();
			
			this.outcsv = new CsvWriter(outcsv, ',', Charset.forName("UTF-8"));
			this.outcsv.setTextQualifier('\"');
			this.outcsv.setForceQualifier(true);
			String output_headers[] = {"idstudent", "surname1", "surname2", "name", "misscount", "excussedcount", "delaycount", "expulsioncount"};
			this.outcsv.writeRecord(output_headers);

		} catch (Exception e) {
			System.err.println("AM_CSVMissReport: Init error !!!");
			System.err.println(e);
		}
	}
	/**
	 * @param args
	 * @throws Exception 
	 */
	public static void main(String[] args) throws Exception {
		if(args.length!=5) {
			System.err.println("Usage: AM_CSVMissReport <propertiesfile> <startdate> <enddate> <idgroup> <out.csv>\n\n" +
					"Writes a miss count report in out.csv for a group.\n" +
					"<propertiesfile> Java properties file with database connection parameters\n" +
					"<startdate> SQL Date, report only counts misses after this date (included)\n" +
					"<enddate> SQL Date, report only counts misses befor this date (included)\n" +
					"<idgroup>\n" +
					"<out.csv> output report");
					
			System.exit(1);
		}
		
		AM_CSVMissReport app = new AM_CSVMissReport(args[0], args[4]);
		app.doit(args[1], args[2], args[3]);
	}

	private void doit(String dateA, String dateB, String idgroup) throws Exception {
	
		try {
			
			ResultSet result = statement.executeQuery("SELECT student.idstudent, student.surname1, student.surname2, student.name,sum(if (miss.type=1,1,0)) 'misscount', sum(if (miss.type = 2,1,0)) 'excusedcount',         sum(if (miss.type =3,1,0)) 'delaycount',sum(if (miss.type = 4,1,0)) 'expulsioncount'   FROM   student INNER JOIN miss ON miss.student_idstudent=student.idstudent INNER JOIN group_has_student ON group_has_student.student_idstudent=student.idstudent WHERE group_idgroup=" + idgroup + " AND miss.date BETWEEN '" + dateA + "' AND '" + dateB + "' GROUP BY student.idstudent ORDER BY student.surname1, student.surname2, student.name;");
			
			while(result.next()) {
				String record[] = {String.valueOf(result.getInt("idstudent")), result.getString("surname1"), result.getString("surname2"), result.getString("name"), String.valueOf(result.getInt("misscount")), String.valueOf(result.getInt("excusedcount")), String.valueOf(result.getInt("delaycount")), String.valueOf(result.getInt("expulsioncount"))};
				outcsv.writeRecord(record);
			}
		} catch (Exception e) {
			System.err.println("AM_CSVMissReport: Exception !!!");
			System.err.println(e);
		}
		
		outcsv.close();
		con.close();
	}
	
}
