/*
    AttendanceManager
    Copyright (C) 2010  Victor Carceler

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as
    published by the Free Software Foundation, either version 3 of the
    License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>
 */

/*
 * Usage: AM_ImportClassblocks <propertiesfile> <in.csv>
 * 
 * Loads classblocks from CSV file <in.csv> into database. 
 * 
 * <propertiesfile> Java properties file with database connection parameters
 * <in.csv> CSV file with classblocks. Header: "idsubject", "idgroup", "day_of_week", "start", "end"
 *    
 *    Where:
 *    			day_of_week: 2->Monday, 3->Tuesday ...
 *    			start: SQL TIME
 *    			end: SQL TIME
 */

package org.iespuigcastellar.amtools;

import java.nio.charset.Charset;
import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.Statement;
import java.util.Arrays;
import java.util.Properties;
import java.io.FileInputStream;
import com.csvreader.CsvReader;

public class AM_ImportClassblocks {
	
	private Properties properties;
	private Connection con;
	private Statement statement;
	
	private CsvReader incsv;
	
	public AM_ImportClassblocks(String propertiesname, String incsv) {
		try {
			FileInputStream file = new FileInputStream(propertiesname); 
			properties = new Properties();
			properties.load(file);
			file.close();
			
			Class.forName("com.mysql.jdbc.Driver");
			String url = "jdbc:mysql://" + properties.getProperty("mysql_server") + ":" + properties.getProperty("mysql_port") + "/" + properties.getProperty("mysql_database");
			con = DriverManager.getConnection(url, properties.getProperty("mysql_user"), properties.getProperty("mysql_password"));
			statement = con.createStatement();
			
			this.incsv = new CsvReader(incsv, ',', Charset.forName("UTF-8"));
			this.incsv.readHeaders();
			String headers[] = this.incsv.getHeaders();
			String reference_headers[] = {"idsubject", "idgroup", "day_of_week", "start", "end"};
			if(!Arrays.equals(headers, reference_headers)){
				System.err.println("AM_ImportClassblocks: Wrong in.csv format");
				System.err.println(headers[0]);
				System.exit(2);
			}

		} catch (Exception e) {
			System.err.println("AM_ImportClassblocks: Init error !!!");
			System.err.println(e);
			System.exit(3);
		}
	}

	/**
	 * @param args
	 * @throws Exception 
	 */
	public static void main(String[] args) throws Exception {
		
		if(args.length!=2) {
			System.err.println("Usage: AM_ImportClassblocks <propertiesfile> <in.csv> \n\n" +
  
					"Loads classblocks from CSV file <in.csv> into database.\n\n" +
  
					"<propertiesfile> Java properties file with database connection parameters\n" +
					"<in.csv> CSV file with students. Header: 'idsubject', 'idgroup', 'day_of_week' (2-> Monday, 3->Tuesday, ...), 'start' (SQL TIME), 'end' (SQL TIME)\n");
			System.exit(1);
		}
		
		AM_ImportClassblocks app = new AM_ImportClassblocks(args[0], args[1]);
		app.doit();
	}

	private void doit() throws Exception{
		while (incsv.readRecord()) {
			statement.execute("INSERT INTO classblock VALUES(null, '"+ incsv.get("idsubject") + "', '" + incsv.get("idgroup") + "', '"+ incsv.get("day_of_week") +"', '" + incsv.get("start") + "', '" + incsv.get("end") + "');");
		}
		
		incsv.close();
		con.close();
	}
}
