/*
    AttendanceManager
    Copyright (C) 2010  Victor Carceler

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as
    published by the Free Software Foundation, either version 3 of the
    License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>
 */

/*
 * Usage: AM_ImportSubjects <propertiesfile> <in.csv> <out.csv>
 * 
 * Loads subjects from CSV file <in.csv> into database. Outputs to <out.csv>
 * the subjects with assigned ID.
 * 
 * <propertiesfile> Java properties file with database connection parameters
 * <in.csv> CSV file with subjects. Header: "idteacher", "name", "comment"
 * <out.csv> CSV file. Header: "idsubject", "idteacher", "name", "comment"
 */

package org.iespuigcastellar.amtools;

import java.nio.charset.Charset;
import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.ResultSet;
import java.sql.Statement;
import java.util.Arrays;
import java.util.Properties;
import java.io.FileInputStream;
import com.csvreader.CsvReader;
import com.csvreader.CsvWriter;

public class AM_ImportSubjects {

	private Properties properties;
	private Connection con;
	private Statement statement;
	
	private CsvReader incsv;
	private CsvWriter outcsv;
	
	public AM_ImportSubjects(String propertiesname, String incsv, String outcsv) {
		try {
			FileInputStream file = new FileInputStream(propertiesname); 
			properties = new Properties();
			properties.load(file);
			file.close();
			
			Class.forName("com.mysql.jdbc.Driver");
			String url = "jdbc:mysql://" + properties.getProperty("mysql_server") + ":" + properties.getProperty("mysql_port") + "/" + properties.getProperty("mysql_database");
			con = DriverManager.getConnection(url, properties.getProperty("mysql_user"), properties.getProperty("mysql_password"));
			statement = con.createStatement();
			
			this.incsv = new CsvReader(incsv, ',', Charset.forName("UTF-8"));
			this.incsv.readHeaders();
			String headers[] = this.incsv.getHeaders();
			String reference_headers[] = {"idteacher", "name", "comment"};
			if(!Arrays.equals(headers, reference_headers)){
				System.err.println("AM_ImportSubjects: Wrong in.csv format");
				System.err.println(headers[0]);
				System.exit(2);
			}
			
			this.outcsv = new CsvWriter(outcsv, ',', Charset.forName("UTF-8"));
			this.outcsv.setTextQualifier('\"');
			this.outcsv.setForceQualifier(true);
			String output_headers[] = {"idsubject", "idteacher", "name", "comment"};
			this.outcsv.writeRecord(output_headers);

		} catch (Exception e) {
			System.err.println("AM_ImportSubjects: Init error !!!");
			System.err.println(e);
			System.exit(3);
		}
	}
	/**
	 * @param args
	 * @throws Exception 
	 */
	public static void main(String[] args) throws Exception {
		
		if(args.length!=3) {
			System.err.println("Usage: AM_ImportSubjects <propertiesfile> <in.csv> <out.csv>\n\n" +
  
					"Loads subjects from CSV file <in.csv> into database. Outputs to <out.csv>\n" +
					"the subjects with assigned ID.\n\n" +
  
					"<propertiesfile> Java properties file with database connection parameters\n" +
					"<in.csv> CSV file with students. Header: 'idteacher', 'name', 'comment'\n" +
					"<out.csv> CSV file. Header: 'idsubject', 'idteacher', 'name', 'comment'");
			System.exit(1);
		}
		
		AM_ImportSubjects app = new AM_ImportSubjects(args[0], args[1], args[2]);
		app.doit();
	}
	
	private void doit() throws Exception {
		while (incsv.readRecord()) {
			statement.execute("INSERT INTO subject VALUES(null, '"+ incsv.get("idteacher") + "', '" + incsv.get("name") + "', '" + incsv.get("comment") + "');");
			ResultSet result = statement.executeQuery("SELECT * FROM subject WHERE subject.idsubject = LAST_INSERT_ID();");

			if(result.next()) {
				String record[] = {String.valueOf(result.getInt("idsubject")), String.valueOf(result.getInt("teacher_idteacher")), result.getString("name"), result.getString("comment")};
				outcsv.writeRecord(record);
			}
		}
		
		incsv.close();
		outcsv.close();
		con.close();
	}

}
